summaryrefslogtreecommitdiffstats
path: root/sync/internal_api/syncapi_internal.h
diff options
context:
space:
mode:
authorakalin@chromium.org <akalin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-22 07:35:26 +0000
committerakalin@chromium.org <akalin@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-22 07:35:26 +0000
commit06aeba61e19bc26ec0ff993b56a6a1a4a20d72bd (patch)
treeedcc4117871b482005d719b9fa20d921826929e6 /sync/internal_api/syncapi_internal.h
parent855cf34fcf1f41eb7a12afdbae58fec830a1ea9b (diff)
downloadchromium_src-06aeba61e19bc26ec0ff993b56a6a1a4a20d72bd.zip
chromium_src-06aeba61e19bc26ec0ff993b56a6a1a4a20d72bd.tar.gz
chromium_src-06aeba61e19bc26ec0ff993b56a6a1a4a20d72bd.tar.bz2
[Sync] Rename sync_api to csync
BUG=128060 TEST= Review URL: https://chromiumcodereview.appspot.com/10601002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@143557 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'sync/internal_api/syncapi_internal.h')
-rw-r--r--sync/internal_api/syncapi_internal.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sync/internal_api/syncapi_internal.h b/sync/internal_api/syncapi_internal.h
index caeed2b..da8de78 100644
--- a/sync/internal_api/syncapi_internal.h
+++ b/sync/internal_api/syncapi_internal.h
@@ -6,7 +6,7 @@
#define SYNC_INTERNAL_API_SYNCAPI_INTERNAL_H_
// The functions defined are shared among some of the classes that implement
// the internal sync_api. They are not to be used by clients of the API.
#include <string>
@@ -19,12 +19,12 @@ class EntitySpecifics;
class PasswordSpecificsData;
}
-namespace sync_api {
+namespace csync {
sync_pb::PasswordSpecificsData* DecryptPasswordSpecifics(
const sync_pb::EntitySpecifics& specifics,
csync::Cryptographer* crypto);
-void SyncAPINameToServerName(const std::string& sync_api_name,
+void SyncAPINameToServerName(const std::string& csync_name,
std::string* out);
bool IsNameServerIllegalAfterTrimming(const std::string& name);
@@ -6,7 +6,7 @@
#define SYNC_INTERNAL_API_SYNCAPI_INTERNAL_H_
// The functions defined are shared among some of the classes that implement
-// the internal sync_api. They are not to be used by clients of the API.
+// the internal csync. They are not to be used by clients of the API.
#include <string>